summaryrefslogtreecommitdiffstats
path: root/contrib/rom-o-matic/build.php
diff options
context:
space:
mode:
authorMichael Brown2010-04-19 21:16:01 +0200
committerMichael Brown2010-04-20 00:43:39 +0200
commit8406115834d38bb743e01f35bfd36e835532415e (patch)
treeee1e3106e2cdc645d911ba5643f8414b21fc4c3e /contrib/rom-o-matic/build.php
parent[eepro100] Remove link-state checking (diff)
downloadipxe-8406115834d38bb743e01f35bfd36e835532415e.tar.gz
ipxe-8406115834d38bb743e01f35bfd36e835532415e.tar.xz
ipxe-8406115834d38bb743e01f35bfd36e835532415e.zip
[build] Rename gPXE to iPXE
Access to the gpxe.org and etherboot.org domains and associated resources has been revoked by the registrant of the domain. Work around this problem by renaming project from gPXE to iPXE, and updating URLs to match. Also update README, LOG and COPYRIGHTS to remove obsolete information. Signed-off-by: Michael Brown <mcb30@ipxe.org>
Diffstat (limited to 'contrib/rom-o-matic/build.php')
-rw-r--r--contrib/rom-o-matic/build.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/contrib/rom-o-matic/build.php b/contrib/rom-o-matic/build.php
index 1d9ee303..3101b3e3 100644
--- a/contrib/rom-o-matic/build.php
+++ b/contrib/rom-o-matic/build.php
@@ -158,19 +158,19 @@ $build_dir = mktempcopy ( "$src_dir", "/tmp", "MDCROM" );
$config_dir = $build_dir . "/config";
// Write config files with supplied flags
-write_gpxe_config_files ( $config_dir, $flags );
+write_ipxe_config_files ( $config_dir, $flags );
// Handle a possible embedded script
$emb_script_cmd = "";
$embedded_script = isset ( $_POST['embedded_script'] ) ? $_POST['embedded_script'] : "";
if ( $embedded_script != "" ) {
- $emb_script_path = "$build_dir" . "/script0.gpxe";
+ $emb_script_path = "$build_dir" . "/script0.ipxe";
- if ( substr ( $embedded_script, 0, 5 ) != "#!gpxe" ) {
- $embedded_script = "#!gpxe\n" . $embedded_script;
+ if ( substr ( $embedded_script, 0, 5 ) != "#!ipxe" ) {
+ $embedded_script = "#!ipxe\n" . $embedded_script;
}
// gPXE 0.9.7 doesn't like '\r\n" in the shebang...
$embedded_script = str_replace ( "\r\n", "\n", $embedded_script );
write_file_from_string ( $emb_script_path, $embedded_script );
@@ -239,7 +239,7 @@ if ( $status == 0 ) {
// Delete build directory as soon as it is not needed
rm_build_dir ();
- $output_filename = "gpxe-${version}-${nic}.${fmt_extension}";
+ $output_filename = "ipxe-${version}-${nic}.${fmt_extension}";
// Try to force IE to handle downloading right.
Header ( "Cache-control: private");
@@ -158,19 +158,19 @@ $build_dir = mktempcopy ( "$src_dir", "/tmp", "MDCROM" );
}
- // gPXE 0.9.7 doesn't like '\r\n" in the shebang...
+ // iPXE 0.9.7 doesn't like '\r\n" in the shebang...
$embedded_script = str_replace ( "\r\n", "\n", $embedded_script );
write_file_from_string ( $emb_script_path, $embedded_script );